# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PluginArgs', 'Plugin']

@pulumi.input_type
class PluginArgs:
    def __init__(__self__, *,
                 config_json: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 route_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 strict_match: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Plugin resource.
        :param pulumi.Input[builtins.str] config_json: this is the configuration json for how you want to configure the plugin.  The json is passed straight through to kong as is.  You can get the json config from the Kong documentation
               page of the plugin you are configuring
        :param pulumi.Input[builtins.str] consumer_id: the consumer id you want to configure the plugin for
        :param pulumi.Input[builtins.bool] enabled: whether the plugin is enabled or not, use if you want to keep the plugin installed but disable it
        :param pulumi.Input[builtins.str] route_id: the route id that you want to configure the plugin for
        :param pulumi.Input[builtins.str] service_id: the service id that you want to configure the plugin for
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Plugin for grouping and filtering
        """
        if config_json is not None:
            pulumi.set(__self__, "config_json", config_json)
        if consumer_id is not None:
            pulumi.set(__self__, "consumer_id", consumer_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if route_id is not None:
            pulumi.set(__self__, "route_id", route_id)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if strict_match is not None:
            pulumi.set(__self__, "strict_match", strict_match)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="configJson")
    def config_json(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        this is the configuration json for how you want to configure the plugin.  The json is passed straight through to kong as is.  You can get the json config from the Kong documentation
        page of the plugin you are configuring
        """
        return pulumi.get(self, "config_json")

    @config_json.setter
    def config_json(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_json", value)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the consumer id you want to configure the plugin for
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        whether the plugin is enabled or not, use if you want to keep the plugin installed but disable it
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="routeId")
    def route_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the route id that you want to configure the plugin for
        """
        return pulumi.get(self, "route_id")

    @route_id.setter
    def route_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_id", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the service id that you want to configure the plugin for
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="strictMatch")
    def strict_match(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "strict_match")

    @strict_match.setter
    def strict_match(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "strict_match", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the Plugin for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _PluginState:
    def __init__(__self__, *,
                 computed_config: Optional[pulumi.Input[builtins.str]] = None,
                 config_json: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 route_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 strict_match: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Plugin resources.
        :param pulumi.Input[builtins.str] config_json: this is the configuration json for how you want to configure the plugin.  The json is passed straight through to kong as is.  You can get the json config from the Kong documentation
               page of the plugin you are configuring
        :param pulumi.Input[builtins.str] consumer_id: the consumer id you want to configure the plugin for
        :param pulumi.Input[builtins.bool] enabled: whether the plugin is enabled or not, use if you want to keep the plugin installed but disable it
        :param pulumi.Input[builtins.str] route_id: the route id that you want to configure the plugin for
        :param pulumi.Input[builtins.str] service_id: the service id that you want to configure the plugin for
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Plugin for grouping and filtering
        """
        if computed_config is not None:
            pulumi.set(__self__, "computed_config", computed_config)
        if config_json is not None:
            pulumi.set(__self__, "config_json", config_json)
        if consumer_id is not None:
            pulumi.set(__self__, "consumer_id", consumer_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if route_id is not None:
            pulumi.set(__self__, "route_id", route_id)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if strict_match is not None:
            pulumi.set(__self__, "strict_match", strict_match)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="computedConfig")
    def computed_config(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "computed_config")

    @computed_config.setter
    def computed_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "computed_config", value)

    @property
    @pulumi.getter(name="configJson")
    def config_json(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        this is the configuration json for how you want to configure the plugin.  The json is passed straight through to kong as is.  You can get the json config from the Kong documentation
        page of the plugin you are configuring
        """
        return pulumi.get(self, "config_json")

    @config_json.setter
    def config_json(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_json", value)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the consumer id you want to configure the plugin for
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        whether the plugin is enabled or not, use if you want to keep the plugin installed but disable it
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="routeId")
    def route_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the route id that you want to configure the plugin for
        """
        return pulumi.get(self, "route_id")

    @route_id.setter
    def route_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_id", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the service id that you want to configure the plugin for
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="strictMatch")
    def strict_match(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "strict_match")

    @strict_match.setter
    def strict_match(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "strict_match", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the Plugin for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("kong:index/plugin:Plugin")
class Plugin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_json: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 route_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 strict_match: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## # Plugin

        The plugin resource maps directly onto the json for the API endpoint in Kong.  For more information on the parameters [see the Kong Api create documentation](https://docs.konghq.com/gateway-oss/2.5.x/admin-api/#plugin-object).
        The `config_json` is passed through to the plugin to configure it as is.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 5,
        \\x09\\x09"hour" : 1000
        \\x09}
        \"\"\")
        ```
        To apply a plugin to a consumer use the `consumer_id` property, for example:

        ```python
        import pulumi
        import pulumi_kong as kong

        plugin_consumer = kong.Consumer("plugin_consumer",
            username="PluginUser",
            custom_id="567")
        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            consumer_id=plugin_consumer.id,
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 5,
        \\x09\\x09"hour" : 1000
        \\x09}
        \"\"\")
        ```

        To apply a plugin to a service use the `service_id` property, for example:

        ```python
        import pulumi
        import pulumi_kong as kong

        service = kong.Service("service",
            name="test",
            protocol="http",
            host="test.org")
        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            service_id=service.id,
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 10,
        \\x09\\x09"hour" : 2000
        \\x09}
        \"\"\")
        ```

        To apply a plugin to a route use the `route_id` property, for example:

        ```python
        import pulumi
        import pulumi_kong as kong

        service = kong.Service("service",
            name="test",
            protocol="http",
            host="test.org")
        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            enabled=True,
            service_id=service.id,
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 11,
        \\x09\\x09"hour" : 4000
        \\x09}
        \"\"\")
        ```

        ## Import

        To import a plugin:

        ```sh
        $ pulumi import kong:index/plugin:Plugin <plugin_identifier> <plugin_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] config_json: this is the configuration json for how you want to configure the plugin.  The json is passed straight through to kong as is.  You can get the json config from the Kong documentation
               page of the plugin you are configuring
        :param pulumi.Input[builtins.str] consumer_id: the consumer id you want to configure the plugin for
        :param pulumi.Input[builtins.bool] enabled: whether the plugin is enabled or not, use if you want to keep the plugin installed but disable it
        :param pulumi.Input[builtins.str] route_id: the route id that you want to configure the plugin for
        :param pulumi.Input[builtins.str] service_id: the service id that you want to configure the plugin for
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Plugin for grouping and filtering
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PluginArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # Plugin

        The plugin resource maps directly onto the json for the API endpoint in Kong.  For more information on the parameters [see the Kong Api create documentation](https://docs.konghq.com/gateway-oss/2.5.x/admin-api/#plugin-object).
        The `config_json` is passed through to the plugin to configure it as is.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 5,
        \\x09\\x09"hour" : 1000
        \\x09}
        \"\"\")
        ```
        To apply a plugin to a consumer use the `consumer_id` property, for example:

        ```python
        import pulumi
        import pulumi_kong as kong

        plugin_consumer = kong.Consumer("plugin_consumer",
            username="PluginUser",
            custom_id="567")
        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            consumer_id=plugin_consumer.id,
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 5,
        \\x09\\x09"hour" : 1000
        \\x09}
        \"\"\")
        ```

        To apply a plugin to a service use the `service_id` property, for example:

        ```python
        import pulumi
        import pulumi_kong as kong

        service = kong.Service("service",
            name="test",
            protocol="http",
            host="test.org")
        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            service_id=service.id,
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 10,
        \\x09\\x09"hour" : 2000
        \\x09}
        \"\"\")
        ```

        To apply a plugin to a route use the `route_id` property, for example:

        ```python
        import pulumi
        import pulumi_kong as kong

        service = kong.Service("service",
            name="test",
            protocol="http",
            host="test.org")
        rate_limit = kong.Plugin("rate_limit",
            name="rate-limiting",
            enabled=True,
            service_id=service.id,
            config_json=\"\"\"\\x09{
        \\x09\\x09"second": 11,
        \\x09\\x09"hour" : 4000
        \\x09}
        \"\"\")
        ```

        ## Import

        To import a plugin:

        ```sh
        $ pulumi import kong:index/plugin:Plugin <plugin_identifier> <plugin_id>
        ```

        :param str resource_name: The name of the resource.
        :param PluginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PluginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_json: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 route_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 strict_match: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PluginArgs.__new__(PluginArgs)

            __props__.__dict__["config_json"] = config_json
            __props__.__dict__["consumer_id"] = consumer_id
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["route_id"] = route_id
            __props__.__dict__["service_id"] = service_id
            __props__.__dict__["strict_match"] = strict_match
            __props__.__dict__["tags"] = tags
            __props__.__dict__["computed_config"] = None
        super(Plugin, __self__).__init__(
            'kong:index/plugin:Plugin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            computed_config: Optional[pulumi.Input[builtins.str]] = None,
            config_json: Optional[pulumi.Input[builtins.str]] = None,
            consumer_id: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            route_id: Optional[pulumi.Input[builtins.str]] = None,
            service_id: Optional[pulumi.Input[builtins.str]] = None,
            strict_match: Optional[pulumi.Input[builtins.bool]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'Plugin':
        """
        Get an existing Plugin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] config_json: this is the configuration json for how you want to configure the plugin.  The json is passed straight through to kong as is.  You can get the json config from the Kong documentation
               page of the plugin you are configuring
        :param pulumi.Input[builtins.str] consumer_id: the consumer id you want to configure the plugin for
        :param pulumi.Input[builtins.bool] enabled: whether the plugin is enabled or not, use if you want to keep the plugin installed but disable it
        :param pulumi.Input[builtins.str] route_id: the route id that you want to configure the plugin for
        :param pulumi.Input[builtins.str] service_id: the service id that you want to configure the plugin for
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Plugin for grouping and filtering
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PluginState.__new__(_PluginState)

        __props__.__dict__["computed_config"] = computed_config
        __props__.__dict__["config_json"] = config_json
        __props__.__dict__["consumer_id"] = consumer_id
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["route_id"] = route_id
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["strict_match"] = strict_match
        __props__.__dict__["tags"] = tags
        return Plugin(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="computedConfig")
    def computed_config(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "computed_config")

    @property
    @pulumi.getter(name="configJson")
    def config_json(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        this is the configuration json for how you want to configure the plugin.  The json is passed straight through to kong as is.  You can get the json config from the Kong documentation
        page of the plugin you are configuring
        """
        return pulumi.get(self, "config_json")

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        the consumer id you want to configure the plugin for
        """
        return pulumi.get(self, "consumer_id")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        whether the plugin is enabled or not, use if you want to keep the plugin installed but disable it
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="routeId")
    def route_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        the route id that you want to configure the plugin for
        """
        return pulumi.get(self, "route_id")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        the service id that you want to configure the plugin for
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="strictMatch")
    def strict_match(self) -> pulumi.Output[Optional[builtins.bool]]:
        return pulumi.get(self, "strict_match")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of strings associated with the Plugin for grouping and filtering
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ServiceArgs', 'Service']

@pulumi.input_type
class ServiceArgs:
    def __init__(__self__, *,
                 protocol: pulumi.Input[builtins.str],
                 ca_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 client_certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connect_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 path: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 read_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 retries: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tls_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_verify_depth: Optional[pulumi.Input[builtins.int]] = None,
                 write_timeout: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a Service resource.
        :param pulumi.Input[builtins.str] protocol: Protocol to use
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ca_certificate_ids: A of CA Certificate IDs (created from the certificate resource). that are used to build the trust store while verifying upstream server’s TLS certificate.
        :param pulumi.Input[builtins.str] client_certificate_id: ID of Certificate to be used as client certificate while TLS handshaking to the upstream server. Use ID from `Certificate` resource
        :param pulumi.Input[builtins.int] connect_timeout: Connection timeout. Default(ms): 60000
        :param pulumi.Input[builtins.str] host: Host to map to
        :param pulumi.Input[builtins.str] name: Service name
        :param pulumi.Input[builtins.str] path: Path to map to
        :param pulumi.Input[builtins.int] port: Port to map to. Default: 80
        :param pulumi.Input[builtins.int] read_timeout: Read timeout. Default(ms): 60000
        :param pulumi.Input[builtins.int] retries: Number of retries. Default: 5
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Service for grouping and filtering.
        :param pulumi.Input[builtins.bool] tls_verify: Whether to enable verification of upstream server TLS certificate. If not set then the nginx default is respected.
        :param pulumi.Input[builtins.int] tls_verify_depth: Maximum depth of chain while verifying Upstream server’s TLS certificate.
        :param pulumi.Input[builtins.int] write_timeout: Write timout. Default(ms): 60000
        """
        pulumi.set(__self__, "protocol", protocol)
        if ca_certificate_ids is not None:
            pulumi.set(__self__, "ca_certificate_ids", ca_certificate_ids)
        if client_certificate_id is not None:
            pulumi.set(__self__, "client_certificate_id", client_certificate_id)
        if connect_timeout is not None:
            pulumi.set(__self__, "connect_timeout", connect_timeout)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if read_timeout is not None:
            pulumi.set(__self__, "read_timeout", read_timeout)
        if retries is not None:
            pulumi.set(__self__, "retries", retries)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tls_verify is not None:
            pulumi.set(__self__, "tls_verify", tls_verify)
        if tls_verify_depth is not None:
            pulumi.set(__self__, "tls_verify_depth", tls_verify_depth)
        if write_timeout is not None:
            pulumi.set(__self__, "write_timeout", write_timeout)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        Protocol to use
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="caCertificateIds")
    def ca_certificate_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A of CA Certificate IDs (created from the certificate resource). that are used to build the trust store while verifying upstream server’s TLS certificate.
        """
        return pulumi.get(self, "ca_certificate_ids")

    @ca_certificate_ids.setter
    def ca_certificate_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ca_certificate_ids", value)

    @property
    @pulumi.getter(name="clientCertificateId")
    def client_certificate_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of Certificate to be used as client certificate while TLS handshaking to the upstream server. Use ID from `Certificate` resource
        """
        return pulumi.get(self, "client_certificate_id")

    @client_certificate_id.setter
    def client_certificate_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_certificate_id", value)

    @property
    @pulumi.getter(name="connectTimeout")
    def connect_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Connection timeout. Default(ms): 60000
        """
        return pulumi.get(self, "connect_timeout")

    @connect_timeout.setter
    def connect_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connect_timeout", value)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Host to map to
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Path to map to
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Port to map to. Default: 80
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="readTimeout")
    def read_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Read timeout. Default(ms): 60000
        """
        return pulumi.get(self, "read_timeout")

    @read_timeout.setter
    def read_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "read_timeout", value)

    @property
    @pulumi.getter
    def retries(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of retries. Default: 5
        """
        return pulumi.get(self, "retries")

    @retries.setter
    def retries(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retries", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the Service for grouping and filtering.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tlsVerify")
    def tls_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable verification of upstream server TLS certificate. If not set then the nginx default is respected.
        """
        return pulumi.get(self, "tls_verify")

    @tls_verify.setter
    def tls_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "tls_verify", value)

    @property
    @pulumi.getter(name="tlsVerifyDepth")
    def tls_verify_depth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum depth of chain while verifying Upstream server’s TLS certificate.
        """
        return pulumi.get(self, "tls_verify_depth")

    @tls_verify_depth.setter
    def tls_verify_depth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "tls_verify_depth", value)

    @property
    @pulumi.getter(name="writeTimeout")
    def write_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Write timout. Default(ms): 60000
        """
        return pulumi.get(self, "write_timeout")

    @write_timeout.setter
    def write_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "write_timeout", value)


@pulumi.input_type
class _ServiceState:
    def __init__(__self__, *,
                 ca_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 client_certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connect_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 path: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 read_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 retries: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tls_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_verify_depth: Optional[pulumi.Input[builtins.int]] = None,
                 write_timeout: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering Service resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ca_certificate_ids: A of CA Certificate IDs (created from the certificate resource). that are used to build the trust store while verifying upstream server’s TLS certificate.
        :param pulumi.Input[builtins.str] client_certificate_id: ID of Certificate to be used as client certificate while TLS handshaking to the upstream server. Use ID from `Certificate` resource
        :param pulumi.Input[builtins.int] connect_timeout: Connection timeout. Default(ms): 60000
        :param pulumi.Input[builtins.str] host: Host to map to
        :param pulumi.Input[builtins.str] name: Service name
        :param pulumi.Input[builtins.str] path: Path to map to
        :param pulumi.Input[builtins.int] port: Port to map to. Default: 80
        :param pulumi.Input[builtins.str] protocol: Protocol to use
        :param pulumi.Input[builtins.int] read_timeout: Read timeout. Default(ms): 60000
        :param pulumi.Input[builtins.int] retries: Number of retries. Default: 5
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Service for grouping and filtering.
        :param pulumi.Input[builtins.bool] tls_verify: Whether to enable verification of upstream server TLS certificate. If not set then the nginx default is respected.
        :param pulumi.Input[builtins.int] tls_verify_depth: Maximum depth of chain while verifying Upstream server’s TLS certificate.
        :param pulumi.Input[builtins.int] write_timeout: Write timout. Default(ms): 60000
        """
        if ca_certificate_ids is not None:
            pulumi.set(__self__, "ca_certificate_ids", ca_certificate_ids)
        if client_certificate_id is not None:
            pulumi.set(__self__, "client_certificate_id", client_certificate_id)
        if connect_timeout is not None:
            pulumi.set(__self__, "connect_timeout", connect_timeout)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if read_timeout is not None:
            pulumi.set(__self__, "read_timeout", read_timeout)
        if retries is not None:
            pulumi.set(__self__, "retries", retries)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tls_verify is not None:
            pulumi.set(__self__, "tls_verify", tls_verify)
        if tls_verify_depth is not None:
            pulumi.set(__self__, "tls_verify_depth", tls_verify_depth)
        if write_timeout is not None:
            pulumi.set(__self__, "write_timeout", write_timeout)

    @property
    @pulumi.getter(name="caCertificateIds")
    def ca_certificate_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A of CA Certificate IDs (created from the certificate resource). that are used to build the trust store while verifying upstream server’s TLS certificate.
        """
        return pulumi.get(self, "ca_certificate_ids")

    @ca_certificate_ids.setter
    def ca_certificate_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ca_certificate_ids", value)

    @property
    @pulumi.getter(name="clientCertificateId")
    def client_certificate_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of Certificate to be used as client certificate while TLS handshaking to the upstream server. Use ID from `Certificate` resource
        """
        return pulumi.get(self, "client_certificate_id")

    @client_certificate_id.setter
    def client_certificate_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_certificate_id", value)

    @property
    @pulumi.getter(name="connectTimeout")
    def connect_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Connection timeout. Default(ms): 60000
        """
        return pulumi.get(self, "connect_timeout")

    @connect_timeout.setter
    def connect_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connect_timeout", value)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Host to map to
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Path to map to
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Port to map to. Default: 80
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Protocol to use
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="readTimeout")
    def read_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Read timeout. Default(ms): 60000
        """
        return pulumi.get(self, "read_timeout")

    @read_timeout.setter
    def read_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "read_timeout", value)

    @property
    @pulumi.getter
    def retries(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of retries. Default: 5
        """
        return pulumi.get(self, "retries")

    @retries.setter
    def retries(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retries", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the Service for grouping and filtering.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tlsVerify")
    def tls_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable verification of upstream server TLS certificate. If not set then the nginx default is respected.
        """
        return pulumi.get(self, "tls_verify")

    @tls_verify.setter
    def tls_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "tls_verify", value)

    @property
    @pulumi.getter(name="tlsVerifyDepth")
    def tls_verify_depth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum depth of chain while verifying Upstream server’s TLS certificate.
        """
        return pulumi.get(self, "tls_verify_depth")

    @tls_verify_depth.setter
    def tls_verify_depth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "tls_verify_depth", value)

    @property
    @pulumi.getter(name="writeTimeout")
    def write_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Write timout. Default(ms): 60000
        """
        return pulumi.get(self, "write_timeout")

    @write_timeout.setter
    def write_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "write_timeout", value)


@pulumi.type_token("kong:index/service:Service")
class Service(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ca_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 client_certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connect_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 path: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 read_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 retries: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tls_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_verify_depth: Optional[pulumi.Input[builtins.int]] = None,
                 write_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        ## # Service

        The service resource maps directly onto the json for the service endpoint in Kong.  For more information on the parameters [see the Kong Service create documentation](https://docs.konghq.com/gateway-oss/2.5.x/admin-api/#service-object).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        service = kong.Service("service",
            name="test",
            protocol="http",
            host="test.org",
            port=8080,
            path="/mypath",
            retries=5,
            connect_timeout=1000,
            write_timeout=2000,
            read_timeout=3000)
        ```

        To use a client certificate and ca certificates combine with certificate resource (note protocol must be `https`):

        ```python
        import pulumi
        import pulumi_kong as kong

        certificate = kong.Certificate("certificate",
            certificate=\"\"\"    -----BEGIN CERTIFICATE-----
            ......
            -----END CERTIFICATE-----
        \"\"\",
            private_key=\"\"\"    -----BEGIN PRIVATE KEY-----
            .....
            -----END PRIVATE KEY-----
        \"\"\",
            snis=["foo.com"])
        ca = kong.Certificate("ca",
            certificate=\"\"\"    -----BEGIN CERTIFICATE-----
            ......
            -----END CERTIFICATE-----
        \"\"\",
            private_key=\"\"\"    -----BEGIN PRIVATE KEY-----
            .....
            -----END PRIVATE KEY-----
        \"\"\",
            snis=["ca.com"])
        service = kong.Service("service",
            name="test",
            protocol="https",
            host="test.org",
            tls_verify=True,
            tls_verify_depth=2,
            client_certificate_id=certificate.id,
            ca_certificate_ids=[ca.id])
        ```

        ## Import

        To import a service:

        ```sh
        $ pulumi import kong:index/service:Service <service_identifier> <service_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ca_certificate_ids: A of CA Certificate IDs (created from the certificate resource). that are used to build the trust store while verifying upstream server’s TLS certificate.
        :param pulumi.Input[builtins.str] client_certificate_id: ID of Certificate to be used as client certificate while TLS handshaking to the upstream server. Use ID from `Certificate` resource
        :param pulumi.Input[builtins.int] connect_timeout: Connection timeout. Default(ms): 60000
        :param pulumi.Input[builtins.str] host: Host to map to
        :param pulumi.Input[builtins.str] name: Service name
        :param pulumi.Input[builtins.str] path: Path to map to
        :param pulumi.Input[builtins.int] port: Port to map to. Default: 80
        :param pulumi.Input[builtins.str] protocol: Protocol to use
        :param pulumi.Input[builtins.int] read_timeout: Read timeout. Default(ms): 60000
        :param pulumi.Input[builtins.int] retries: Number of retries. Default: 5
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Service for grouping and filtering.
        :param pulumi.Input[builtins.bool] tls_verify: Whether to enable verification of upstream server TLS certificate. If not set then the nginx default is respected.
        :param pulumi.Input[builtins.int] tls_verify_depth: Maximum depth of chain while verifying Upstream server’s TLS certificate.
        :param pulumi.Input[builtins.int] write_timeout: Write timout. Default(ms): 60000
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # Service

        The service resource maps directly onto the json for the service endpoint in Kong.  For more information on the parameters [see the Kong Service create documentation](https://docs.konghq.com/gateway-oss/2.5.x/admin-api/#service-object).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        service = kong.Service("service",
            name="test",
            protocol="http",
            host="test.org",
            port=8080,
            path="/mypath",
            retries=5,
            connect_timeout=1000,
            write_timeout=2000,
            read_timeout=3000)
        ```

        To use a client certificate and ca certificates combine with certificate resource (note protocol must be `https`):

        ```python
        import pulumi
        import pulumi_kong as kong

        certificate = kong.Certificate("certificate",
            certificate=\"\"\"    -----BEGIN CERTIFICATE-----
            ......
            -----END CERTIFICATE-----
        \"\"\",
            private_key=\"\"\"    -----BEGIN PRIVATE KEY-----
            .....
            -----END PRIVATE KEY-----
        \"\"\",
            snis=["foo.com"])
        ca = kong.Certificate("ca",
            certificate=\"\"\"    -----BEGIN CERTIFICATE-----
            ......
            -----END CERTIFICATE-----
        \"\"\",
            private_key=\"\"\"    -----BEGIN PRIVATE KEY-----
            .....
            -----END PRIVATE KEY-----
        \"\"\",
            snis=["ca.com"])
        service = kong.Service("service",
            name="test",
            protocol="https",
            host="test.org",
            tls_verify=True,
            tls_verify_depth=2,
            client_certificate_id=certificate.id,
            ca_certificate_ids=[ca.id])
        ```

        ## Import

        To import a service:

        ```sh
        $ pulumi import kong:index/service:Service <service_identifier> <service_id>
        ```

        :param str resource_name: The name of the resource.
        :param ServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ca_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 client_certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connect_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 path: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 read_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 retries: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tls_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_verify_depth: Optional[pulumi.Input[builtins.int]] = None,
                 write_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceArgs.__new__(ServiceArgs)

            __props__.__dict__["ca_certificate_ids"] = ca_certificate_ids
            __props__.__dict__["client_certificate_id"] = client_certificate_id
            __props__.__dict__["connect_timeout"] = connect_timeout
            __props__.__dict__["host"] = host
            __props__.__dict__["name"] = name
            __props__.__dict__["path"] = path
            __props__.__dict__["port"] = port
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["read_timeout"] = read_timeout
            __props__.__dict__["retries"] = retries
            __props__.__dict__["tags"] = tags
            __props__.__dict__["tls_verify"] = tls_verify
            __props__.__dict__["tls_verify_depth"] = tls_verify_depth
            __props__.__dict__["write_timeout"] = write_timeout
        super(Service, __self__).__init__(
            'kong:index/service:Service',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ca_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            client_certificate_id: Optional[pulumi.Input[builtins.str]] = None,
            connect_timeout: Optional[pulumi.Input[builtins.int]] = None,
            host: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            path: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            read_timeout: Optional[pulumi.Input[builtins.int]] = None,
            retries: Optional[pulumi.Input[builtins.int]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            tls_verify: Optional[pulumi.Input[builtins.bool]] = None,
            tls_verify_depth: Optional[pulumi.Input[builtins.int]] = None,
            write_timeout: Optional[pulumi.Input[builtins.int]] = None) -> 'Service':
        """
        Get an existing Service resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ca_certificate_ids: A of CA Certificate IDs (created from the certificate resource). that are used to build the trust store while verifying upstream server’s TLS certificate.
        :param pulumi.Input[builtins.str] client_certificate_id: ID of Certificate to be used as client certificate while TLS handshaking to the upstream server. Use ID from `Certificate` resource
        :param pulumi.Input[builtins.int] connect_timeout: Connection timeout. Default(ms): 60000
        :param pulumi.Input[builtins.str] host: Host to map to
        :param pulumi.Input[builtins.str] name: Service name
        :param pulumi.Input[builtins.str] path: Path to map to
        :param pulumi.Input[builtins.int] port: Port to map to. Default: 80
        :param pulumi.Input[builtins.str] protocol: Protocol to use
        :param pulumi.Input[builtins.int] read_timeout: Read timeout. Default(ms): 60000
        :param pulumi.Input[builtins.int] retries: Number of retries. Default: 5
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Service for grouping and filtering.
        :param pulumi.Input[builtins.bool] tls_verify: Whether to enable verification of upstream server TLS certificate. If not set then the nginx default is respected.
        :param pulumi.Input[builtins.int] tls_verify_depth: Maximum depth of chain while verifying Upstream server’s TLS certificate.
        :param pulumi.Input[builtins.int] write_timeout: Write timout. Default(ms): 60000
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceState.__new__(_ServiceState)

        __props__.__dict__["ca_certificate_ids"] = ca_certificate_ids
        __props__.__dict__["client_certificate_id"] = client_certificate_id
        __props__.__dict__["connect_timeout"] = connect_timeout
        __props__.__dict__["host"] = host
        __props__.__dict__["name"] = name
        __props__.__dict__["path"] = path
        __props__.__dict__["port"] = port
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["read_timeout"] = read_timeout
        __props__.__dict__["retries"] = retries
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tls_verify"] = tls_verify
        __props__.__dict__["tls_verify_depth"] = tls_verify_depth
        __props__.__dict__["write_timeout"] = write_timeout
        return Service(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="caCertificateIds")
    def ca_certificate_ids(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A of CA Certificate IDs (created from the certificate resource). that are used to build the trust store while verifying upstream server’s TLS certificate.
        """
        return pulumi.get(self, "ca_certificate_ids")

    @property
    @pulumi.getter(name="clientCertificateId")
    def client_certificate_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        ID of Certificate to be used as client certificate while TLS handshaking to the upstream server. Use ID from `Certificate` resource
        """
        return pulumi.get(self, "client_certificate_id")

    @property
    @pulumi.getter(name="connectTimeout")
    def connect_timeout(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Connection timeout. Default(ms): 60000
        """
        return pulumi.get(self, "connect_timeout")

    @property
    @pulumi.getter
    def host(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Host to map to
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Path to map to
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Port to map to. Default: 80
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        Protocol to use
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="readTimeout")
    def read_timeout(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Read timeout. Default(ms): 60000
        """
        return pulumi.get(self, "read_timeout")

    @property
    @pulumi.getter
    def retries(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Number of retries. Default: 5
        """
        return pulumi.get(self, "retries")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of strings associated with the Service for grouping and filtering.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tlsVerify")
    def tls_verify(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to enable verification of upstream server TLS certificate. If not set then the nginx default is respected.
        """
        return pulumi.get(self, "tls_verify")

    @property
    @pulumi.getter(name="tlsVerifyDepth")
    def tls_verify_depth(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Maximum depth of chain while verifying Upstream server’s TLS certificate.
        """
        return pulumi.get(self, "tls_verify_depth")

    @property
    @pulumi.getter(name="writeTimeout")
    def write_timeout(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Write timout. Default(ms): 60000
        """
        return pulumi.get(self, "write_timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ConsumerJwtAuthArgs', 'ConsumerJwtAuth']

@pulumi.input_type
class ConsumerJwtAuthArgs:
    def __init__(__self__, *,
                 consumer_id: pulumi.Input[builtins.str],
                 rsa_public_key: pulumi.Input[builtins.str],
                 algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 secret: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a ConsumerJwtAuth resource.
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured with jwt auth
        :param pulumi.Input[builtins.str] rsa_public_key: If algorithm is `RS256` or `ES256`, the public key (in PEM format) to use to verify the token’s signature
        :param pulumi.Input[builtins.str] algorithm: The algorithm used to verify the token’s signature. Can be HS256, HS384, HS512, RS256, or ES256, Default is `HS256`
        :param pulumi.Input[builtins.str] key: A unique string identifying the credential. If left out, it will be auto-generated.
        :param pulumi.Input[builtins.str] secret: If algorithm is `HS256` or `ES256`, the secret used to sign JWTs for this credential. If left out, will be auto-generated
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer JWT auth for grouping and filtering
        """
        pulumi.set(__self__, "consumer_id", consumer_id)
        pulumi.set(__self__, "rsa_public_key", rsa_public_key)
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> pulumi.Input[builtins.str]:
        """
        the id of the consumer to be configured with jwt auth
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter(name="rsaPublicKey")
    def rsa_public_key(self) -> pulumi.Input[builtins.str]:
        """
        If algorithm is `RS256` or `ES256`, the public key (in PEM format) to use to verify the token’s signature
        """
        return pulumi.get(self, "rsa_public_key")

    @rsa_public_key.setter
    def rsa_public_key(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rsa_public_key", value)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The algorithm used to verify the token’s signature. Can be HS256, HS384, HS512, RS256, or ES256, Default is `HS256`
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A unique string identifying the credential. If left out, it will be auto-generated.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        If algorithm is `HS256` or `ES256`, the secret used to sign JWTs for this credential. If left out, will be auto-generated
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the consumer JWT auth for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ConsumerJwtAuthState:
    def __init__(__self__, *,
                 algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 rsa_public_key: Optional[pulumi.Input[builtins.str]] = None,
                 secret: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ConsumerJwtAuth resources.
        :param pulumi.Input[builtins.str] algorithm: The algorithm used to verify the token’s signature. Can be HS256, HS384, HS512, RS256, or ES256, Default is `HS256`
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured with jwt auth
        :param pulumi.Input[builtins.str] key: A unique string identifying the credential. If left out, it will be auto-generated.
        :param pulumi.Input[builtins.str] rsa_public_key: If algorithm is `RS256` or `ES256`, the public key (in PEM format) to use to verify the token’s signature
        :param pulumi.Input[builtins.str] secret: If algorithm is `HS256` or `ES256`, the secret used to sign JWTs for this credential. If left out, will be auto-generated
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer JWT auth for grouping and filtering
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if consumer_id is not None:
            pulumi.set(__self__, "consumer_id", consumer_id)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if rsa_public_key is not None:
            pulumi.set(__self__, "rsa_public_key", rsa_public_key)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The algorithm used to verify the token’s signature. Can be HS256, HS384, HS512, RS256, or ES256, Default is `HS256`
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the id of the consumer to be configured with jwt auth
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A unique string identifying the credential. If left out, it will be auto-generated.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter(name="rsaPublicKey")
    def rsa_public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        If algorithm is `RS256` or `ES256`, the public key (in PEM format) to use to verify the token’s signature
        """
        return pulumi.get(self, "rsa_public_key")

    @rsa_public_key.setter
    def rsa_public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rsa_public_key", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        If algorithm is `HS256` or `ES256`, the secret used to sign JWTs for this credential. If left out, will be auto-generated
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the consumer JWT auth for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("kong:index/consumerJwtAuth:ConsumerJwtAuth")
class ConsumerJwtAuth(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 rsa_public_key: Optional[pulumi.Input[builtins.str]] = None,
                 secret: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## # ConsumerJwtAuth

        Consumer jwt auth is a resource that allows you to configure the jwt auth plugin for a consumer.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        my_consumer = kong.Consumer("my_consumer",
            username="User1",
            custom_id="123")
        jwt_plugin = kong.Plugin("jwt_plugin",
            name="jwt",
            config_json=\"\"\"\\x09{
        \\x09\\x09"claims_to_verify": ["exp"]
        \\x09}
        \"\"\")
        consumer_jwt_config = kong.ConsumerJwtAuth("consumer_jwt_config",
            consumer_id=my_consumer.id,
            algorithm="HS256",
            key="my_key",
            rsa_public_key="foo",
            secret="my_secret")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] algorithm: The algorithm used to verify the token’s signature. Can be HS256, HS384, HS512, RS256, or ES256, Default is `HS256`
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured with jwt auth
        :param pulumi.Input[builtins.str] key: A unique string identifying the credential. If left out, it will be auto-generated.
        :param pulumi.Input[builtins.str] rsa_public_key: If algorithm is `RS256` or `ES256`, the public key (in PEM format) to use to verify the token’s signature
        :param pulumi.Input[builtins.str] secret: If algorithm is `HS256` or `ES256`, the secret used to sign JWTs for this credential. If left out, will be auto-generated
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer JWT auth for grouping and filtering
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConsumerJwtAuthArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # ConsumerJwtAuth

        Consumer jwt auth is a resource that allows you to configure the jwt auth plugin for a consumer.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        my_consumer = kong.Consumer("my_consumer",
            username="User1",
            custom_id="123")
        jwt_plugin = kong.Plugin("jwt_plugin",
            name="jwt",
            config_json=\"\"\"\\x09{
        \\x09\\x09"claims_to_verify": ["exp"]
        \\x09}
        \"\"\")
        consumer_jwt_config = kong.ConsumerJwtAuth("consumer_jwt_config",
            consumer_id=my_consumer.id,
            algorithm="HS256",
            key="my_key",
            rsa_public_key="foo",
            secret="my_secret")
        ```

        :param str resource_name: The name of the resource.
        :param ConsumerJwtAuthArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConsumerJwtAuthArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 rsa_public_key: Optional[pulumi.Input[builtins.str]] = None,
                 secret: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConsumerJwtAuthArgs.__new__(ConsumerJwtAuthArgs)

            __props__.__dict__["algorithm"] = algorithm
            if consumer_id is None and not opts.urn:
                raise TypeError("Missing required property 'consumer_id'")
            __props__.__dict__["consumer_id"] = consumer_id
            __props__.__dict__["key"] = key
            if rsa_public_key is None and not opts.urn:
                raise TypeError("Missing required property 'rsa_public_key'")
            __props__.__dict__["rsa_public_key"] = rsa_public_key
            __props__.__dict__["secret"] = secret
            __props__.__dict__["tags"] = tags
        super(ConsumerJwtAuth, __self__).__init__(
            'kong:index/consumerJwtAuth:ConsumerJwtAuth',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            algorithm: Optional[pulumi.Input[builtins.str]] = None,
            consumer_id: Optional[pulumi.Input[builtins.str]] = None,
            key: Optional[pulumi.Input[builtins.str]] = None,
            rsa_public_key: Optional[pulumi.Input[builtins.str]] = None,
            secret: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'ConsumerJwtAuth':
        """
        Get an existing ConsumerJwtAuth resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] algorithm: The algorithm used to verify the token’s signature. Can be HS256, HS384, HS512, RS256, or ES256, Default is `HS256`
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured with jwt auth
        :param pulumi.Input[builtins.str] key: A unique string identifying the credential. If left out, it will be auto-generated.
        :param pulumi.Input[builtins.str] rsa_public_key: If algorithm is `RS256` or `ES256`, the public key (in PEM format) to use to verify the token’s signature
        :param pulumi.Input[builtins.str] secret: If algorithm is `HS256` or `ES256`, the secret used to sign JWTs for this credential. If left out, will be auto-generated
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer JWT auth for grouping and filtering
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConsumerJwtAuthState.__new__(_ConsumerJwtAuthState)

        __props__.__dict__["algorithm"] = algorithm
        __props__.__dict__["consumer_id"] = consumer_id
        __props__.__dict__["key"] = key
        __props__.__dict__["rsa_public_key"] = rsa_public_key
        __props__.__dict__["secret"] = secret
        __props__.__dict__["tags"] = tags
        return ConsumerJwtAuth(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def algorithm(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The algorithm used to verify the token’s signature. Can be HS256, HS384, HS512, RS256, or ES256, Default is `HS256`
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> pulumi.Output[builtins.str]:
        """
        the id of the consumer to be configured with jwt auth
        """
        return pulumi.get(self, "consumer_id")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A unique string identifying the credential. If left out, it will be auto-generated.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="rsaPublicKey")
    def rsa_public_key(self) -> pulumi.Output[builtins.str]:
        """
        If algorithm is `RS256` or `ES256`, the public key (in PEM format) to use to verify the token’s signature
        """
        return pulumi.get(self, "rsa_public_key")

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        If algorithm is `HS256` or `ES256`, the secret used to sign JWTs for this credential. If left out, will be auto-generated
        """
        return pulumi.get(self, "secret")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of strings associated with the consumer JWT auth for grouping and filtering
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .certificate import *
from .consumer import *
from .consumer_acl import *
from .consumer_basic_auth import *
from .consumer_jwt_auth import *
from .consumer_key_auth import *
from .consumer_oauth2 import *
from .plugin import *
from .provider import *
from .route import *
from .service import *
from .target import *
from .upstream import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_kong.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_kong.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "kong",
  "mod": "index/certificate",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumer",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumer:Consumer": "Consumer"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerAcl",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerAcl:ConsumerAcl": "ConsumerAcl"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerBasicAuth",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerBasicAuth:ConsumerBasicAuth": "ConsumerBasicAuth"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerJwtAuth",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerJwtAuth:ConsumerJwtAuth": "ConsumerJwtAuth"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerKeyAuth",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerKeyAuth:ConsumerKeyAuth": "ConsumerKeyAuth"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerOauth2",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerOauth2:ConsumerOauth2": "ConsumerOauth2"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/plugin",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/plugin:Plugin": "Plugin"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/route",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/route:Route": "Route"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/service",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/service:Service": "Service"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/target",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/target:Target": "Target"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/upstream",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/upstream:Upstream": "Upstream"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "kong",
  "token": "pulumi:providers:kong",
  "fqn": "pulumi_kong",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'RouteDestination',
    'RouteHeader',
    'RouteSource',
    'UpstreamHealthchecks',
    'UpstreamHealthchecksActive',
    'UpstreamHealthchecksActiveHealthy',
    'UpstreamHealthchecksActiveUnhealthy',
    'UpstreamHealthchecksPassive',
    'UpstreamHealthchecksPassiveHealthy',
    'UpstreamHealthchecksPassiveUnhealthy',
]

@pulumi.output_type
class RouteDestination(dict):
    def __init__(__self__, *,
                 ip: Optional[builtins.str] = None,
                 port: Optional[builtins.int] = None):
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def ip(self) -> Optional[builtins.str]:
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.int]:
        return pulumi.get(self, "port")


@pulumi.output_type
class RouteHeader(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 values: Sequence[builtins.str]):
        """
        :param builtins.str name: The name of the route
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the route
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class RouteSource(dict):
    def __init__(__self__, *,
                 ip: Optional[builtins.str] = None,
                 port: Optional[builtins.int] = None):
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def ip(self) -> Optional[builtins.str]:
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.int]:
        return pulumi.get(self, "port")


@pulumi.output_type
class UpstreamHealthchecks(dict):
    def __init__(__self__, *,
                 active: Optional['outputs.UpstreamHealthchecksActive'] = None,
                 passive: Optional['outputs.UpstreamHealthchecksPassive'] = None):
        if active is not None:
            pulumi.set(__self__, "active", active)
        if passive is not None:
            pulumi.set(__self__, "passive", passive)

    @property
    @pulumi.getter
    def active(self) -> Optional['outputs.UpstreamHealthchecksActive']:
        return pulumi.get(self, "active")

    @property
    @pulumi.getter
    def passive(self) -> Optional['outputs.UpstreamHealthchecksPassive']:
        return pulumi.get(self, "passive")


@pulumi.output_type
class UpstreamHealthchecksActive(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "httpPath":
            suggest = "http_path"
        elif key == "httpsSni":
            suggest = "https_sni"
        elif key == "httpsVerifyCertificate":
            suggest = "https_verify_certificate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UpstreamHealthchecksActive. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UpstreamHealthchecksActive.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UpstreamHealthchecksActive.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 concurrency: Optional[builtins.int] = None,
                 healthy: Optional['outputs.UpstreamHealthchecksActiveHealthy'] = None,
                 http_path: Optional[builtins.str] = None,
                 https_sni: Optional[builtins.str] = None,
                 https_verify_certificate: Optional[builtins.bool] = None,
                 timeout: Optional[builtins.int] = None,
                 type: Optional[builtins.str] = None,
                 unhealthy: Optional['outputs.UpstreamHealthchecksActiveUnhealthy'] = None):
        if concurrency is not None:
            pulumi.set(__self__, "concurrency", concurrency)
        if healthy is not None:
            pulumi.set(__self__, "healthy", healthy)
        if http_path is not None:
            pulumi.set(__self__, "http_path", http_path)
        if https_sni is not None:
            pulumi.set(__self__, "https_sni", https_sni)
        if https_verify_certificate is not None:
            pulumi.set(__self__, "https_verify_certificate", https_verify_certificate)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if unhealthy is not None:
            pulumi.set(__self__, "unhealthy", unhealthy)

    @property
    @pulumi.getter
    def concurrency(self) -> Optional[builtins.int]:
        return pulumi.get(self, "concurrency")

    @property
    @pulumi.getter
    def healthy(self) -> Optional['outputs.UpstreamHealthchecksActiveHealthy']:
        return pulumi.get(self, "healthy")

    @property
    @pulumi.getter(name="httpPath")
    def http_path(self) -> Optional[builtins.str]:
        return pulumi.get(self, "http_path")

    @property
    @pulumi.getter(name="httpsSni")
    def https_sni(self) -> Optional[builtins.str]:
        return pulumi.get(self, "https_sni")

    @property
    @pulumi.getter(name="httpsVerifyCertificate")
    def https_verify_certificate(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "https_verify_certificate")

    @property
    @pulumi.getter
    def timeout(self) -> Optional[builtins.int]:
        return pulumi.get(self, "timeout")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def unhealthy(self) -> Optional['outputs.UpstreamHealthchecksActiveUnhealthy']:
        return pulumi.get(self, "unhealthy")


@pulumi.output_type
class UpstreamHealthchecksActiveHealthy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "httpStatuses":
            suggest = "http_statuses"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UpstreamHealthchecksActiveHealthy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UpstreamHealthchecksActiveHealthy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UpstreamHealthchecksActiveHealthy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 http_statuses: Optional[Sequence[builtins.int]] = None,
                 interval: Optional[builtins.int] = None,
                 successes: Optional[builtins.int] = None):
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if successes is not None:
            pulumi.set(__self__, "successes", successes)

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[Sequence[builtins.int]]:
        return pulumi.get(self, "http_statuses")

    @property
    @pulumi.getter
    def interval(self) -> Optional[builtins.int]:
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter
    def successes(self) -> Optional[builtins.int]:
        return pulumi.get(self, "successes")


@pulumi.output_type
class UpstreamHealthchecksActiveUnhealthy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "httpFailures":
            suggest = "http_failures"
        elif key == "httpStatuses":
            suggest = "http_statuses"
        elif key == "tcpFailures":
            suggest = "tcp_failures"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UpstreamHealthchecksActiveUnhealthy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UpstreamHealthchecksActiveUnhealthy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UpstreamHealthchecksActiveUnhealthy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 http_failures: Optional[builtins.int] = None,
                 http_statuses: Optional[Sequence[builtins.int]] = None,
                 interval: Optional[builtins.int] = None,
                 tcp_failures: Optional[builtins.int] = None,
                 timeouts: Optional[builtins.int] = None):
        if http_failures is not None:
            pulumi.set(__self__, "http_failures", http_failures)
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if tcp_failures is not None:
            pulumi.set(__self__, "tcp_failures", tcp_failures)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter(name="httpFailures")
    def http_failures(self) -> Optional[builtins.int]:
        return pulumi.get(self, "http_failures")

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[Sequence[builtins.int]]:
        return pulumi.get(self, "http_statuses")

    @property
    @pulumi.getter
    def interval(self) -> Optional[builtins.int]:
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="tcpFailures")
    def tcp_failures(self) -> Optional[builtins.int]:
        return pulumi.get(self, "tcp_failures")

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[builtins.int]:
        return pulumi.get(self, "timeouts")


@pulumi.output_type
class UpstreamHealthchecksPassive(dict):
    def __init__(__self__, *,
                 healthy: Optional['outputs.UpstreamHealthchecksPassiveHealthy'] = None,
                 type: Optional[builtins.str] = None,
                 unhealthy: Optional['outputs.UpstreamHealthchecksPassiveUnhealthy'] = None):
        if healthy is not None:
            pulumi.set(__self__, "healthy", healthy)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if unhealthy is not None:
            pulumi.set(__self__, "unhealthy", unhealthy)

    @property
    @pulumi.getter
    def healthy(self) -> Optional['outputs.UpstreamHealthchecksPassiveHealthy']:
        return pulumi.get(self, "healthy")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def unhealthy(self) -> Optional['outputs.UpstreamHealthchecksPassiveUnhealthy']:
        return pulumi.get(self, "unhealthy")


@pulumi.output_type
class UpstreamHealthchecksPassiveHealthy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "httpStatuses":
            suggest = "http_statuses"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UpstreamHealthchecksPassiveHealthy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UpstreamHealthchecksPassiveHealthy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UpstreamHealthchecksPassiveHealthy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 http_statuses: Optional[Sequence[builtins.int]] = None,
                 successes: Optional[builtins.int] = None):
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if successes is not None:
            pulumi.set(__self__, "successes", successes)

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[Sequence[builtins.int]]:
        return pulumi.get(self, "http_statuses")

    @property
    @pulumi.getter
    def successes(self) -> Optional[builtins.int]:
        return pulumi.get(self, "successes")


@pulumi.output_type
class UpstreamHealthchecksPassiveUnhealthy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "httpFailures":
            suggest = "http_failures"
        elif key == "httpStatuses":
            suggest = "http_statuses"
        elif key == "tcpFailures":
            suggest = "tcp_failures"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UpstreamHealthchecksPassiveUnhealthy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UpstreamHealthchecksPassiveUnhealthy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UpstreamHealthchecksPassiveUnhealthy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 http_failures: Optional[builtins.int] = None,
                 http_statuses: Optional[Sequence[builtins.int]] = None,
                 tcp_failures: Optional[builtins.int] = None,
                 timeouts: Optional[builtins.int] = None):
        if http_failures is not None:
            pulumi.set(__self__, "http_failures", http_failures)
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if tcp_failures is not None:
            pulumi.set(__self__, "tcp_failures", tcp_failures)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter(name="httpFailures")
    def http_failures(self) -> Optional[builtins.int]:
        return pulumi.get(self, "http_failures")

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[Sequence[builtins.int]]:
        return pulumi.get(self, "http_statuses")

    @property
    @pulumi.getter(name="tcpFailures")
    def tcp_failures(self) -> Optional[builtins.int]:
        return pulumi.get(self, "tcp_failures")

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[builtins.int]:
        return pulumi.get(self, "timeouts")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'RouteDestinationArgs',
    'RouteDestinationArgsDict',
    'RouteHeaderArgs',
    'RouteHeaderArgsDict',
    'RouteSourceArgs',
    'RouteSourceArgsDict',
    'UpstreamHealthchecksArgs',
    'UpstreamHealthchecksArgsDict',
    'UpstreamHealthchecksActiveArgs',
    'UpstreamHealthchecksActiveArgsDict',
    'UpstreamHealthchecksActiveHealthyArgs',
    'UpstreamHealthchecksActiveHealthyArgsDict',
    'UpstreamHealthchecksActiveUnhealthyArgs',
    'UpstreamHealthchecksActiveUnhealthyArgsDict',
    'UpstreamHealthchecksPassiveArgs',
    'UpstreamHealthchecksPassiveArgsDict',
    'UpstreamHealthchecksPassiveHealthyArgs',
    'UpstreamHealthchecksPassiveHealthyArgsDict',
    'UpstreamHealthchecksPassiveUnhealthyArgs',
    'UpstreamHealthchecksPassiveUnhealthyArgsDict',
]

MYPY = False

if not MYPY:
    class RouteDestinationArgsDict(TypedDict):
        ip: NotRequired[pulumi.Input[builtins.str]]
        port: NotRequired[pulumi.Input[builtins.int]]
elif False:
    RouteDestinationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteDestinationArgs:
    def __init__(__self__, *,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None):
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class RouteHeaderArgsDict(TypedDict):
        name: pulumi.Input[builtins.str]
        """
        The name of the route
        """
        values: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]
elif False:
    RouteHeaderArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteHeaderArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 values: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        """
        :param pulumi.Input[builtins.str] name: The name of the route
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the route
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "values", value)


if not MYPY:
    class RouteSourceArgsDict(TypedDict):
        ip: NotRequired[pulumi.Input[builtins.str]]
        port: NotRequired[pulumi.Input[builtins.int]]
elif False:
    RouteSourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteSourceArgs:
    def __init__(__self__, *,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None):
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class UpstreamHealthchecksArgsDict(TypedDict):
        active: NotRequired[pulumi.Input['UpstreamHealthchecksActiveArgsDict']]
        passive: NotRequired[pulumi.Input['UpstreamHealthchecksPassiveArgsDict']]
elif False:
    UpstreamHealthchecksArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UpstreamHealthchecksArgs:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input['UpstreamHealthchecksActiveArgs']] = None,
                 passive: Optional[pulumi.Input['UpstreamHealthchecksPassiveArgs']] = None):
        if active is not None:
            pulumi.set(__self__, "active", active)
        if passive is not None:
            pulumi.set(__self__, "passive", passive)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input['UpstreamHealthchecksActiveArgs']]:
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input['UpstreamHealthchecksActiveArgs']]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter
    def passive(self) -> Optional[pulumi.Input['UpstreamHealthchecksPassiveArgs']]:
        return pulumi.get(self, "passive")

    @passive.setter
    def passive(self, value: Optional[pulumi.Input['UpstreamHealthchecksPassiveArgs']]):
        pulumi.set(self, "passive", value)


if not MYPY:
    class UpstreamHealthchecksActiveArgsDict(TypedDict):
        concurrency: NotRequired[pulumi.Input[builtins.int]]
        healthy: NotRequired[pulumi.Input['UpstreamHealthchecksActiveHealthyArgsDict']]
        http_path: NotRequired[pulumi.Input[builtins.str]]
        https_sni: NotRequired[pulumi.Input[builtins.str]]
        https_verify_certificate: NotRequired[pulumi.Input[builtins.bool]]
        timeout: NotRequired[pulumi.Input[builtins.int]]
        type: NotRequired[pulumi.Input[builtins.str]]
        unhealthy: NotRequired[pulumi.Input['UpstreamHealthchecksActiveUnhealthyArgsDict']]
elif False:
    UpstreamHealthchecksActiveArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UpstreamHealthchecksActiveArgs:
    def __init__(__self__, *,
                 concurrency: Optional[pulumi.Input[builtins.int]] = None,
                 healthy: Optional[pulumi.Input['UpstreamHealthchecksActiveHealthyArgs']] = None,
                 http_path: Optional[pulumi.Input[builtins.str]] = None,
                 https_sni: Optional[pulumi.Input[builtins.str]] = None,
                 https_verify_certificate: Optional[pulumi.Input[builtins.bool]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 unhealthy: Optional[pulumi.Input['UpstreamHealthchecksActiveUnhealthyArgs']] = None):
        if concurrency is not None:
            pulumi.set(__self__, "concurrency", concurrency)
        if healthy is not None:
            pulumi.set(__self__, "healthy", healthy)
        if http_path is not None:
            pulumi.set(__self__, "http_path", http_path)
        if https_sni is not None:
            pulumi.set(__self__, "https_sni", https_sni)
        if https_verify_certificate is not None:
            pulumi.set(__self__, "https_verify_certificate", https_verify_certificate)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if unhealthy is not None:
            pulumi.set(__self__, "unhealthy", unhealthy)

    @property
    @pulumi.getter
    def concurrency(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "concurrency")

    @concurrency.setter
    def concurrency(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "concurrency", value)

    @property
    @pulumi.getter
    def healthy(self) -> Optional[pulumi.Input['UpstreamHealthchecksActiveHealthyArgs']]:
        return pulumi.get(self, "healthy")

    @healthy.setter
    def healthy(self, value: Optional[pulumi.Input['UpstreamHealthchecksActiveHealthyArgs']]):
        pulumi.set(self, "healthy", value)

    @property
    @pulumi.getter(name="httpPath")
    def http_path(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "http_path")

    @http_path.setter
    def http_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http_path", value)

    @property
    @pulumi.getter(name="httpsSni")
    def https_sni(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "https_sni")

    @https_sni.setter
    def https_sni(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "https_sni", value)

    @property
    @pulumi.getter(name="httpsVerifyCertificate")
    def https_verify_certificate(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "https_verify_certificate")

    @https_verify_certificate.setter
    def https_verify_certificate(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "https_verify_certificate", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeout", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def unhealthy(self) -> Optional[pulumi.Input['UpstreamHealthchecksActiveUnhealthyArgs']]:
        return pulumi.get(self, "unhealthy")

    @unhealthy.setter
    def unhealthy(self, value: Optional[pulumi.Input['UpstreamHealthchecksActiveUnhealthyArgs']]):
        pulumi.set(self, "unhealthy", value)


if not MYPY:
    class UpstreamHealthchecksActiveHealthyArgsDict(TypedDict):
        http_statuses: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]
        interval: NotRequired[pulumi.Input[builtins.int]]
        successes: NotRequired[pulumi.Input[builtins.int]]
elif False:
    UpstreamHealthchecksActiveHealthyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UpstreamHealthchecksActiveHealthyArgs:
    def __init__(__self__, *,
                 http_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 successes: Optional[pulumi.Input[builtins.int]] = None):
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if successes is not None:
            pulumi.set(__self__, "successes", successes)

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        return pulumi.get(self, "http_statuses")

    @http_statuses.setter
    def http_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "http_statuses", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter
    def successes(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "successes")

    @successes.setter
    def successes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "successes", value)


if not MYPY:
    class UpstreamHealthchecksActiveUnhealthyArgsDict(TypedDict):
        http_failures: NotRequired[pulumi.Input[builtins.int]]
        http_statuses: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]
        interval: NotRequired[pulumi.Input[builtins.int]]
        tcp_failures: NotRequired[pulumi.Input[builtins.int]]
        timeouts: NotRequired[pulumi.Input[builtins.int]]
elif False:
    UpstreamHealthchecksActiveUnhealthyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UpstreamHealthchecksActiveUnhealthyArgs:
    def __init__(__self__, *,
                 http_failures: Optional[pulumi.Input[builtins.int]] = None,
                 http_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 tcp_failures: Optional[pulumi.Input[builtins.int]] = None,
                 timeouts: Optional[pulumi.Input[builtins.int]] = None):
        if http_failures is not None:
            pulumi.set(__self__, "http_failures", http_failures)
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if tcp_failures is not None:
            pulumi.set(__self__, "tcp_failures", tcp_failures)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter(name="httpFailures")
    def http_failures(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "http_failures")

    @http_failures.setter
    def http_failures(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "http_failures", value)

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        return pulumi.get(self, "http_statuses")

    @http_statuses.setter
    def http_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "http_statuses", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter(name="tcpFailures")
    def tcp_failures(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "tcp_failures")

    @tcp_failures.setter
    def tcp_failures(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "tcp_failures", value)

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeouts", value)


if not MYPY:
    class UpstreamHealthchecksPassiveArgsDict(TypedDict):
        healthy: NotRequired[pulumi.Input['UpstreamHealthchecksPassiveHealthyArgsDict']]
        type: NotRequired[pulumi.Input[builtins.str]]
        unhealthy: NotRequired[pulumi.Input['UpstreamHealthchecksPassiveUnhealthyArgsDict']]
elif False:
    UpstreamHealthchecksPassiveArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UpstreamHealthchecksPassiveArgs:
    def __init__(__self__, *,
                 healthy: Optional[pulumi.Input['UpstreamHealthchecksPassiveHealthyArgs']] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 unhealthy: Optional[pulumi.Input['UpstreamHealthchecksPassiveUnhealthyArgs']] = None):
        if healthy is not None:
            pulumi.set(__self__, "healthy", healthy)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if unhealthy is not None:
            pulumi.set(__self__, "unhealthy", unhealthy)

    @property
    @pulumi.getter
    def healthy(self) -> Optional[pulumi.Input['UpstreamHealthchecksPassiveHealthyArgs']]:
        return pulumi.get(self, "healthy")

    @healthy.setter
    def healthy(self, value: Optional[pulumi.Input['UpstreamHealthchecksPassiveHealthyArgs']]):
        pulumi.set(self, "healthy", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def unhealthy(self) -> Optional[pulumi.Input['UpstreamHealthchecksPassiveUnhealthyArgs']]:
        return pulumi.get(self, "unhealthy")

    @unhealthy.setter
    def unhealthy(self, value: Optional[pulumi.Input['UpstreamHealthchecksPassiveUnhealthyArgs']]):
        pulumi.set(self, "unhealthy", value)


if not MYPY:
    class UpstreamHealthchecksPassiveHealthyArgsDict(TypedDict):
        http_statuses: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]
        successes: NotRequired[pulumi.Input[builtins.int]]
elif False:
    UpstreamHealthchecksPassiveHealthyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UpstreamHealthchecksPassiveHealthyArgs:
    def __init__(__self__, *,
                 http_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 successes: Optional[pulumi.Input[builtins.int]] = None):
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if successes is not None:
            pulumi.set(__self__, "successes", successes)

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        return pulumi.get(self, "http_statuses")

    @http_statuses.setter
    def http_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "http_statuses", value)

    @property
    @pulumi.getter
    def successes(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "successes")

    @successes.setter
    def successes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "successes", value)


if not MYPY:
    class UpstreamHealthchecksPassiveUnhealthyArgsDict(TypedDict):
        http_failures: NotRequired[pulumi.Input[builtins.int]]
        http_statuses: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]
        tcp_failures: NotRequired[pulumi.Input[builtins.int]]
        timeouts: NotRequired[pulumi.Input[builtins.int]]
elif False:
    UpstreamHealthchecksPassiveUnhealthyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UpstreamHealthchecksPassiveUnhealthyArgs:
    def __init__(__self__, *,
                 http_failures: Optional[pulumi.Input[builtins.int]] = None,
                 http_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 tcp_failures: Optional[pulumi.Input[builtins.int]] = None,
                 timeouts: Optional[pulumi.Input[builtins.int]] = None):
        if http_failures is not None:
            pulumi.set(__self__, "http_failures", http_failures)
        if http_statuses is not None:
            pulumi.set(__self__, "http_statuses", http_statuses)
        if tcp_failures is not None:
            pulumi.set(__self__, "tcp_failures", tcp_failures)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter(name="httpFailures")
    def http_failures(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "http_failures")

    @http_failures.setter
    def http_failures(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "http_failures", value)

    @property
    @pulumi.getter(name="httpStatuses")
    def http_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        return pulumi.get(self, "http_statuses")

    @http_statuses.setter
    def http_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "http_statuses", value)

    @property
    @pulumi.getter(name="tcpFailures")
    def tcp_failures(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "tcp_failures")

    @tcp_failures.setter
    def tcp_failures(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "tcp_failures", value)

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input[builtins.int]]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeouts", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ConsumerAclArgs', 'ConsumerAcl']

@pulumi.input_type
class ConsumerAclArgs:
    def __init__(__self__, *,
                 consumer_id: pulumi.Input[builtins.str],
                 group: pulumi.Input[builtins.str],
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a ConsumerAcl resource.
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured
        :param pulumi.Input[builtins.str] group: the acl group
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer acl for grouping and filtering
        """
        pulumi.set(__self__, "consumer_id", consumer_id)
        pulumi.set(__self__, "group", group)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> pulumi.Input[builtins.str]:
        """
        the id of the consumer to be configured
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter
    def group(self) -> pulumi.Input[builtins.str]:
        """
        the acl group
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the consumer acl for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ConsumerAclState:
    def __init__(__self__, *,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 group: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ConsumerAcl resources.
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured
        :param pulumi.Input[builtins.str] group: the acl group
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer acl for grouping and filtering
        """
        if consumer_id is not None:
            pulumi.set(__self__, "consumer_id", consumer_id)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the id of the consumer to be configured
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the acl group
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the consumer acl for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("kong:index/consumerAcl:ConsumerAcl")
class ConsumerAcl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 group: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## # ConsumerAcl

        Consumer ACL is a resource that allows you to configure the acl plugin for a consumer.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        my_consumer = kong.Consumer("my_consumer",
            username="User1",
            custom_id="123")
        acl_plugin = kong.Plugin("acl_plugin",
            name="acl",
            config_json=\"\"\"\\x09{
        \\x09\\x09"allow": ["group1", "group2"]
        \\x09}
        \"\"\")
        consumer_acl = kong.ConsumerAcl("consumer_acl",
            consumer_id=my_consumer.id,
            group="group2",
            tags=[
                "myTag",
                "otherTag",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured
        :param pulumi.Input[builtins.str] group: the acl group
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer acl for grouping and filtering
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConsumerAclArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # ConsumerAcl

        Consumer ACL is a resource that allows you to configure the acl plugin for a consumer.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        my_consumer = kong.Consumer("my_consumer",
            username="User1",
            custom_id="123")
        acl_plugin = kong.Plugin("acl_plugin",
            name="acl",
            config_json=\"\"\"\\x09{
        \\x09\\x09"allow": ["group1", "group2"]
        \\x09}
        \"\"\")
        consumer_acl = kong.ConsumerAcl("consumer_acl",
            consumer_id=my_consumer.id,
            group="group2",
            tags=[
                "myTag",
                "otherTag",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param ConsumerAclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConsumerAclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 group: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConsumerAclArgs.__new__(ConsumerAclArgs)

            if consumer_id is None and not opts.urn:
                raise TypeError("Missing required property 'consumer_id'")
            __props__.__dict__["consumer_id"] = consumer_id
            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
            __props__.__dict__["tags"] = tags
        super(ConsumerAcl, __self__).__init__(
            'kong:index/consumerAcl:ConsumerAcl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            consumer_id: Optional[pulumi.Input[builtins.str]] = None,
            group: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'ConsumerAcl':
        """
        Get an existing ConsumerAcl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] consumer_id: the id of the consumer to be configured
        :param pulumi.Input[builtins.str] group: the acl group
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer acl for grouping and filtering
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConsumerAclState.__new__(_ConsumerAclState)

        __props__.__dict__["consumer_id"] = consumer_id
        __props__.__dict__["group"] = group
        __props__.__dict__["tags"] = tags
        return ConsumerAcl(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> pulumi.Output[builtins.str]:
        """
        the id of the consumer to be configured
        """
        return pulumi.get(self, "consumer_id")

    @property
    @pulumi.getter
    def group(self) -> pulumi.Output[builtins.str]:
        """
        the acl group
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of strings associated with the consumer acl for grouping and filtering
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

kongAdminPassword: Optional[str]
"""
An basic auth password for kong admin
"""

kongAdminToken: Optional[str]
"""
API key for the kong api (Enterprise Edition)
"""

kongAdminUri: Optional[str]
"""
The address of the kong admin url e.g. http://localhost:8001
"""

kongAdminUsername: Optional[str]
"""
An basic auth user for kong admin
"""

kongApiKey: Optional[str]
"""
API key for the kong api (if you have locked it down)
"""

kongWorkspace: Optional[str]
"""
Workspace context (Enterprise Edition)
"""

strictPluginsMatch: Optional[bool]
"""
Should plugins `config_json` field strictly match plugin configuration
"""

tlsSkipVerify: bool
"""
Whether to skip tls verify for https kong api endpoint using self signed or untrusted certs
"""




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('kong')


class _ExportableConfig(types.ModuleType):
    @property
    def kong_admin_password(self) -> Optional[str]:
        """
        An basic auth password for kong admin
        """
        return __config__.get('kongAdminPassword')

    @property
    def kong_admin_token(self) -> Optional[str]:
        """
        API key for the kong api (Enterprise Edition)
        """
        return __config__.get('kongAdminToken')

    @property
    def kong_admin_uri(self) -> Optional[str]:
        """
        The address of the kong admin url e.g. http://localhost:8001
        """
        return __config__.get('kongAdminUri')

    @property
    def kong_admin_username(self) -> Optional[str]:
        """
        An basic auth user for kong admin
        """
        return __config__.get('kongAdminUsername')

    @property
    def kong_api_key(self) -> Optional[str]:
        """
        API key for the kong api (if you have locked it down)
        """
        return __config__.get('kongApiKey')

    @property
    def kong_workspace(self) -> Optional[str]:
        """
        Workspace context (Enterprise Edition)
        """
        return __config__.get('kongWorkspace')

    @property
    def strict_plugins_match(self) -> Optional[bool]:
        """
        Should plugins `config_json` field strictly match plugin configuration
        """
        return __config__.get_bool('strictPluginsMatch') or _utilities.get_env_bool('STRICT_PLUGINS_MATCH')

    @property
    def tls_skip_verify(self) -> bool:
        """
        Whether to skip tls verify for https kong api endpoint using self signed or untrusted certs
        """
        return __config__.get_bool('tlsSkipVerify') or (_utilities.get_env_bool('TLS_SKIP_VERIFY') or False)

